@@ -5,14 +5,6 @@
 #' @param pch Numeric. Type of of point.
 #' @param add.label Logical. Add text annotation: "40 Broad Street"
 #' @param text.size Numeric. Size of text label.
-#' @param ... Additional plotting parameters.
-#' @seealso \code{\link{snowMap}},
-#' \code{\link{addKernelDensity}},
-#' \code{\link{addLandmarks}},
-#' \code{\link{addPlaguePit}},
-#' \code{\link{addSnow}},
-#' \code{\link{addVoronoi}},
-#' \code{\link{addWhitehead}}
 #' @return Add base R point and (optionally) text to a graphics plot.
 #' @export
 #' @examples
@@ -20,7 +12,7 @@
 #' addIndexCase()
 
 addIndexCase <- function(cex = 2, col = "red", pch = 1, add.label = FALSE,
-  text.size = 0.5, ...) {
+  text.size = 0.5) {
 
   index.case <- cholera::fatalities[cholera::fatalities$case == 32, ]
 
