@@ -178,13 +178,7 @@ streetNumberLocator <- function(road.number = 216, zoom = FALSE,
     est.time <- distanceTime(street.length, distance.unit = distance.unit,
       time.unit = time.unit, walking.speed = walking.speed)
 
-    if (time.unit == "hour") {
-      nominal.time <- paste(round(est.time, 1), "hr")
-    } else if (time.unit == "minute") {
-      nominal.time <- paste(round(est.time, 1), "min")
-    } else if (time.unit == "second") {
-      nominal.time <- paste(round(est.time, 1), "sec")
-    }
+    nominal.time <- nominalTime(est.time, time.unit)
 
     if (is.null(distance.unit)) {
      subtitle <- paste(round(street.length, 1), "units;", nominal.time)
