@@ -63,19 +63,20 @@ neighborhoodVoronoi <- function(pump.select = NULL, vestry = FALSE,
   }
 
   if (is.null(pump.select) == FALSE) {
-    if (is.numeric(pump.select) == FALSE) stop("pump.select must be numeric.",
-      call. = FALSE)
+    if (is.numeric(pump.select) == FALSE) {
+      stop("pump.select must be numeric.", call. = FALSE)
+    }
     p.count <- nrow(pump.data)
     p.ID <- seq_len(p.count)
-
     if (any(abs(pump.select) %in% p.ID == FALSE)) {
       stop('With vestry = ', vestry, ', 1 >= |pump.select| <= ', p.count,
         call. = FALSE)
     }
-
     msg1 <- 'If specified,'
-    msg2 <- 'pump.select must include at least 2 different pumps.'
-    if (length(unique(p.ID[pump.select])) < 2) stop(msg1, msg2, call. = FALSE)
+    msg2 <- "'pump.select' must include at least 2 different pumps."
+    if (length(unique(p.ID[pump.select])) < 2) {
+      stop(paste(msg1, msg2), call. = FALSE)
+    }
   }
 
   if (is.null(statistic) == FALSE) {
