@@ -1,5 +1,5 @@
 #' Common auxiliary functions for walking path functions.
-#' walking(), walkingPath(), addMilePosts(), milePosts(), addNeighborhood().
+#' walking(), walkingPath(), addMilePosts(), addNeighborhood().
 #' @noRd
 
 walkingAuxiliaryFunctions <- function() NULL
@@ -372,7 +372,7 @@ areaPointsData <- function(sim.proj.segs, wholes, snow.colors, sim.proj,
 
 # for neighborhoodWalking(), expectedCount() and pearsonResiduals.walking()
 observedExpected <- function(x, n.data) {
-  if (class(x) != "walking") stop('"x"\'s class needs to be "walking".')
+  if (!inherits(x, "walking")) stop('"x"\'s class needs to be "walking".')
 
   dat <- n.data$dat
   edges <- n.data$edges
@@ -552,7 +552,7 @@ observedExpected <- function(x, n.data) {
 }
 
 neighborhoodPathData <- function(x) {
-  if (class(x) != "walking") {
+  if (!inherits(x, "walking")) {
     stop('"x"\'s class needs to be "walking".')
   }
 
